## Lana

```console
    .-.'  `; `-._  __  _
   (_,         .-:'  `; `-._
 ,'o"(        (_,           )
(__,-'      ,'o"(            )>
   (       (__,-'            )
    `-'._.--._(             )
       |||  |||`-'._.--._.-'
                  |||  |||
```

$\textit{\textbf{L}inear \textbf{A}lgebra for \textbf{n}octurnal and \textbf{a}dventurous data scientists}$

## Install 

```console
pip install lana
```
